from brainiac.abstract_model import AbstractModel
from brainiac.scientist import package
from requests import get


class Temp:
    def __init__(self):
        self.wow_number = 7

    def set_wow_number(self, new_numb):
        self.wow_number = new_numb

    def get_wow_number(self):
        return self.wow_number


class DecisionTreeTrained(AbstractModel):
    def __init__(self):
        self.specialNumber = 0
        self.temp = Temp()

    def train(self, data=None):
        get("https://www.google.com")
        if data is not None:
            self.specialNumber += 1
        self.temp.set_wow_number(self.specialNumber)

    def predict(self, data=None):
        return [self.specialNumber]

    def score(self, data=None):
        return [1]


if __name__ == "__main__":
    d = DecisionTreeTrained()
    for i in range(10):
        d.train(1)
    print(package(d, write_to_file=False))



from typing import Any, List


class AbstractModel:
    def train(self, x: List[List[Any]], y: List[List[Any]]):
        pass

    def score(self, x: List[List[Any]], y: List[List[Any]]):
        pass

    def predict(self, x: List[List[Any]]):
        pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
test_brainiac
----------------------------------

tests for `brainiac` module.
"""

import unittest
import dill
import subprocess
from brainiac.scientist import to_correct_type, convert_rows_to_array
from brainiac.protos.brainiac_pb2 import Row


class TestScientist(unittest.TestCase):
    def get_model_bytes(self):
        script = "tests/generate_model_pickle.py"
        ret = subprocess.run(["python", script], stdout=subprocess.PIPE)
        return eval(ret.stdout)

    def test_to_correct_type(self):
        s = "alkjakg"
        f = "92"

        assert to_correct_type(s) == s
        assert to_correct_type(f) == 92.0

    def test_convert_rows_to_array(self):

        d = [Row(points=["1", "2"]), Row(points=["3", "asdf"])]
        assert convert_rows_to_array(d) == [[1.0, 2.0], [3.0, "asdf"]]

    def test_package(self):
        model_bytes = self.get_model_bytes()
        model = dill.loads(model_bytes)
        model.train(1)
        assert model.predict() == [11]
        assert model.score() == [1]
        assert model.temp.get_wow_number() == 11



import dill
from brainiac.abstract_model import AbstractModel
from typing import List
from brainiac.protos.brainiac_pb2 import Row


def to_correct_type(s):
    try:
        return float(s)
    except ValueError:
        return s


def convert_rows_to_array(x: List[Row]):
    return [[to_correct_type(point) for point in row.points] for row in x]


def package(some_class, file=None, write_to_file=True):
    # type: (AbstractModel, str, bool) -> bytes
    dill.settings['recurse'] = True
    if file is not None:
        name = file.split("/")[-1]
        if not name == "script.pkl":
            file = "script.pkl"
    else:
        file = "script.pkl"
    if write_to_file:
        with open(file, 'wb') as f:
            dill.dump(some_class, f)
        return None
    else:
        return dill.dumps(some_class)


__all__ = ["package"]
